==> cozy-ui-122.11.1.tgz: package/transpiled/react/Icons/Mail.js <==
import _extends from "@babel/runtime/helpers/extends";
// Automatically created, please run `scripts/generate-svgr-icon.sh assets/icons/twake/illus/mail.svg` to regenerate;
import React from 'react';

function SvgMail(props) {
  return /*#__PURE__*/React.createElement("svg", _extends({
    viewBox: "0 0 33 33",
    fill: "none"
  }, props), /*#__PURE__*/React.createElement("rect", {
    x: 0.582,
    y: 0.718,
    width: 32,
    height: 32,
    rx: 10.568,
    fill: "url(#mail_svg__paint0_linear_11347_30933)"
  }), /*#__PURE__*/React.createElement("g", {
    filter: "url(#mail_svg__filter0_d_11347_30933)"
  }, /*#__PURE__*/React.createElement("path", {
    fillRule: "evenodd",
    clipRule: "evenodd",
    d: "M7.167 12.492a3.048 3.048 0 00-1.2 2.423v8.7a3.658 3.658 0 003.658 3.658h13.897a3.658 3.658 0 003.658-3.658v-8.7c0-.95-.444-1.847-1.2-2.423l-7.558-5.765a3.048 3.048 0 00-3.697 0l-7.558 5.764zm1.157 2.07v9.18c0 .674.546 1.22 1.22 1.22h14.06a1.22 1.22 0 001.22-1.22v-9.18l-6.852 4.798a2.439 2.439 0 01-2.797 0l-6.851-4.798z",
    fill: "#fff"
  })), /*#__PURE__*/React.createElement("defs", null, /*#__PURE__*/React.createElement("linearGradient", {
    id: "mail_svg__paint0_linear_11347_30933",
    x1: 5.069,
    y1: 29.356,
    x2: 31.831,
    y2: 2.268,
    gradientUnits: "userSpaceOnUse"
  }, /*#__PURE__*/React.createElement("stop", {
    stopColor: "#1E91FF"
  }), /*#__PURE__*/React.createElement("stop", {
    offset: 0.997,
    stopColor: "#2ED9FF"
  })), /*#__PURE__*/React.createElement("filter", {
    id: "mail_svg__filter0_d_11347_30933",
    x: 4.335,
    y: 4.797,
    width: 24.477,
    height: 24.433,
    filterUnits: "userSpaceOnUse",
    colorInterpolationFilters: "sRGB"
  }, /*#__PURE__*/React.createElement("feFlood", {
    floodOpacity: 0,
    result: "BackgroundImageFix"
  }), /*#__PURE__*/React.createElement("feColorMatrix", {
    in: "SourceAlpha",
    values: "0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 127 0",
    result: "hardAlpha"
  }), /*#__PURE__*/React.createElement("feOffset", {
    dy: 0.326
  }), /*#__PURE__*/React.createElement("feGaussianBlur", {
    stdDeviation: 0.816
  }), /*#__PURE__*/React.createElement("feComposite", {
    in2: "hardAlpha",
    operator: "out"
  }), /*#__PURE__*/React.createElement("feColorMatrix", {
    values: "0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0.1 0"
  }), /*#__PURE__*/React.createElement("feBlend", {
    in2: "BackgroundImageFix",
    result: "effect1_dropShadow_11347_30933"
  }), /*#__PURE__*/React.createElement("feBlend", {
    in: "SourceGraphic",
    in2: "effect1_dropShadow_11347_30933",
    result: "shape"
  }))));
}

export default SvgMail;

==> cozy-ui-124.0.0.tgz: package/transpiled/react/Icons/Mail.js <==
import _extends from "@babel/runtime/helpers/extends";
// Automatically created, please run `scripts/generate-svgr-icon.sh assets/icons/illus/mail.svg` to regenerate;
import React from 'react';

function SvgMail(props) {
  return /*#__PURE__*/React.createElement("svg", _extends({
    viewBox: "0 0 32 32",
    fill: "none"
  }, props), /*#__PURE__*/React.createElement("rect", {
    width: 32,
    height: 32,
    rx: 10,
    fill: "url(#mail_svg__paint0_linear_3096_880)"
  }), /*#__PURE__*/React.createElement("g", {
    filter: "url(#mail_svg__filter0_d_3096_880)"
  }, /*#__PURE__*/React.createElement("path", {
    fillRule: "evenodd",
    clipRule: "evenodd",
    d: "M6.585 11.774a3.048 3.048 0 00-1.2 2.423v8.7a3.658 3.658 0 003.658 3.658H22.94a3.658 3.658 0 003.658-3.658v-8.7c0-.95-.444-1.847-1.2-2.423L17.84 6.009a3.048 3.048 0 00-3.697 0l-7.558 5.764zm1.157 2.07v9.18c0 .674.546 1.22 1.22 1.22h14.06a1.22 1.22 0 001.219-1.22v-9.18l-6.85 4.798a2.439 2.439 0 01-2.798 0l-6.851-4.798z",
    fill: "#fff"
  })), /*#__PURE__*/React.createElement("defs", null, /*#__PURE__*/React.createElement("linearGradient", {
    id: "mail_svg__paint0_linear_3096_880",
    x1: 4.487,
    y1: 28.638,
    x2: 31.249,
    y2: 1.55,
    gradientUnits: "userSpaceOnUse"
  }, /*#__PURE__*/React.createElement("stop", {
    stopColor: "#1E91FF"
  }), /*#__PURE__*/React.createElement("stop", {
    offset: 0.997,
    stopColor: "#2ED9FF"
  })), /*#__PURE__*/React.createElement("filter", {
    id: "mail_svg__filter0_d_3096_880",
    x: 3.753,
    y: 4.079,
    width: 24.477,
    height: 24.434,
    filterUnits: "userSpaceOnUse",
    colorInterpolationFilters: "sRGB"
  }, /*#__PURE__*/React.createElement("feFlood", {
    floodOpacity: 0,
    result: "BackgroundImageFix"
  }), /*#__PURE__*/React.createElement("feColorMatrix", {
    in: "SourceAlpha",
    values: "0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 127 0",
    result: "hardAlpha"
  }), /*#__PURE__*/React.createElement("feOffset", {
    dy: 0.326
  }), /*#__PURE__*/React.createElement("feGaussianBlur", {
    stdDeviation: 0.816
  }), /*#__PURE__*/React.createElement("feComposite", {
    in2: "hardAlpha",
    operator: "out"
  }), /*#__PURE__*/React.createElement("feColorMatrix", {
    values: "0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0.1 0"
  }), /*#__PURE__*/React.createElement("feBlend", {
    in2: "BackgroundImageFix",
    result: "effect1_dropShadow_3096_880"
  }), /*#__PURE__*/React.createElement("feBlend", {
    in: "SourceGraphic",
    in2: "effect1_dropShadow_3096_880",
    result: "shape"
  }))));
}

export default SvgMail;
